@@ -5,6 +5,7 @@ from numpy import min as np_min, max as np_max, abs as np_abs, log10
 import matplotlib.pyplot as plt
 import mpl_toolkits.mplot3d.art3d as art3d
 from matplotlib.image import NonUniformImage
+import matplotlib
 
 from SciDataTool.Functions.Plot.init_fig import init_fig
 from SciDataTool.Functions.Plot import COLORS
@@ -147,6 +148,7 @@ def plot_3D(
 
     # Plot
     if type_plot == "stem":
+        cmap = matplotlib.cm.get_cmap(colormap)
         for xi, yi, zi in zip(Xdata, Ydata, Zdata):
             line = art3d.Line3D(
                 *zip((xi, yi, 0), (xi, yi, zi)),
@@ -154,7 +156,7 @@ def plot_3D(
                 marker="o",
                 markersize=3.0,
                 markevery=(1, 1),
-                color=COLORS[0]
+                color=cmap(0)
             )
             ax.add_line(line)
         ax.set_xlim3d(x_max, x_min)
@@ -209,9 +211,12 @@ def plot_3D(
             interpolation="bilinear",
             extent=(x_min, x_max, y_max, y_min),
             cmap=colormap,
+            picker=10,
         )
         im.set_data(Xdata, Ydata, Zdata.T)
         ax.images.append(im)
+        # ax.picker = True
+        # ax.pickradius = 10
         clb = fig.colorbar(im, ax=ax, format=clb_format)
         clb.ax.set_title(zlabel, fontsize=font_size_legend, fontname=font_name)
         clb.ax.tick_params(labelsize=font_size_legend)
@@ -225,7 +230,15 @@ def plot_3D(
         ax.set_ylim([y_min, y_max])
     elif type_plot == "scatter":
         c = ax.scatter(
-            Xdata, Ydata, c=Zdata, marker="s", cmap=colormap, vmin=z_min, vmax=z_max
+            Xdata,
+            Ydata,
+            c=Zdata,
+            marker="s",
+            cmap=colormap,
+            vmin=z_min,
+            vmax=z_max,
+            picker=True,
+            pickradius=5,
         )
         clb = fig.colorbar(c, ax=ax)
         clb.ax.set_title(zlabel, fontsize=font_size_legend, fontname=font_name)
@@ -275,6 +288,8 @@ def plot_3D(
 
     if is_show_fig:
         fig.show()
-        
+
     if win_title:
-        fig.canvas.set_window_title(win_title)
+        manager = plt.get_current_fig_manager()
+        if manager is not None:
+            manager.set_window_title(win_title)
